@@ -1,19 +1,19 @@
 package Data::Validation::Constraints::Date;
 
-# @(#)$Id: Date.pm 57 2008-09-15 18:48:07Z pjf $
+# @(#)$Id: Date.pm 72 2009-03-24 03:14:23Z pjf $
 
 use strict;
 use Moose;
 use CatalystX::Usul::Time;
 
-use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 57 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.2.%d', q$Rev: 72 $ =~ /\d+/gmx );
 
 extends 'Data::Validation::Constraints';
 
 override '_validate' => sub {
    my ($self, $val) = @_;
 
-   return defined CatalystX::Usul::Class::Time->str2time( $val ) ? 1 : 0;
+   return defined CatalystX::Usul::Time->str2time( $val ) ? 1 : 0;
 };
 
 1;
